pub struct RiPrometheusExporter { /* private fields */ }Expand description
Prometheus exporter for managing metrics and generating Grafana dashboards.
This struct provides methods for registering and updating Prometheus metrics, as well as generating Grafana dashboards from these metrics.
Implementations
Sourceimpl RiPrometheusExporter
impl RiPrometheusExporter
Sourcepub fn new() -> RiResult<Self>
pub fn new() -> RiResult<Self>
Creates a new Prometheus exporter instance.
Returns
A new RiPrometheusExporter instance wrapped in RiResult
Sourcepub fn register_histogram(
&self,
name: &str,
help: &str,
buckets: Vec<f64>,
) -> RiResult<()>
pub fn register_histogram( &self, name: &str, help: &str, buckets: Vec<f64>, ) -> RiResult<()>
Sourcepub fn render(&self) -> RiResult<String>
pub fn render(&self) -> RiResult<String>
Renders all metrics in Prometheus text format.
Returns
A string containing all metrics in Prometheus text format wrapped in RiResult
Sourcepub fn add_counter_panel(
&self,
dashboard: &mut RiGrafanaDashboard,
title: &str,
query: &str,
) -> RiResult<()>
pub fn add_counter_panel( &self, dashboard: &mut RiGrafanaDashboard, title: &str, query: &str, ) -> RiResult<()>
Sourcepub fn add_gauge_panel(
&self,
dashboard: &mut RiGrafanaDashboard,
title: &str,
query: &str,
) -> RiResult<()>
pub fn add_gauge_panel( &self, dashboard: &mut RiGrafanaDashboard, title: &str, query: &str, ) -> RiResult<()>
Sourcepub fn add_stat_panel(
&self,
dashboard: &mut RiGrafanaDashboard,
title: &str,
query: &str,
) -> RiResult<()>
pub fn add_stat_panel( &self, dashboard: &mut RiGrafanaDashboard, title: &str, query: &str, ) -> RiResult<()>
Sourcepub fn generate_dashboard(&self, title: &str) -> RiResult<RiGrafanaDashboard>
pub fn generate_dashboard(&self, title: &str) -> RiResult<RiGrafanaDashboard>
Sourcepub fn generate_default_dashboard(&self) -> RiResult<RiGrafanaDashboard>
pub fn generate_default_dashboard(&self) -> RiResult<RiGrafanaDashboard>
Generates a default Grafana dashboard with “Ri Metrics Dashboard” title.
Returns
A default Grafana dashboard wrapped in RiResult